@@ -20,6 +20,7 @@ from lxml import etree
 from lxml.etree import Element
 
 from datapane.client import config as c
+from datapane.client.analytics import capture_event
 from datapane.client.api.common import DPTmpFile, Resource
 from datapane.client.api.dp_object import DPObjectRef
 from datapane.client.api.runtime import _report
@@ -82,7 +83,7 @@ def include_raw(ctx, name):
     env = ctx.environment
     # Escape </script> to prevent 3rd party JS terminating the local report bundle.
     # Note there's an extra "\" because it needs to be escaped at both the python and JS level
-    src = env.loader.get_source(env, name)[0].replace("</script>", "<\\\/script>")
+    src = env.loader.get_source(env, name)[0].replace("</script>", r"<\\/script>")
     return Markup(src)
 
 
@@ -114,7 +115,7 @@ class ReportFileWriter:
         global SKIP_DISPLAY_MSG
 
         # only display once per session, else skip
-        if SKIP_DISPLAY_MSG:
+        if SKIP_DISPLAY_MSG or not c.config.is_public:
             return None
         else:
             SKIP_DISPLAY_MSG = True
@@ -212,7 +213,7 @@ class Report(DPObjectRef):
             has_text: bool = processed_report_doc.xpath("boolean(/Report/Main/Page//Text)")
             if not has_text:
                 display_msg(
-                    "Your report doesn't contain any text - did you know you can add text to your report once published?"
+                    "Your report doesn't contain any text - did you know you can add text to your report from your browser once published?"
                 )
 
             single_block = processed_report_doc.xpath("count(/Report/Main//*)") < 4
@@ -300,11 +301,11 @@ class Report(DPObjectRef):
         _report.append(self)
         if open:
             webbrowser.open_new_tab(self.web_url)
-
         display_msg(
-            text=f"Report successfully published at {self.web_url} - you can edit and add additional text from the link"
+            text=f"Report successfully published at {self.web_url} - you can edit and add additional text online"
         )
 
+    @capture_event("CLI Report Save")
     def save(self, path: str, open: bool = False, name: t.Optional[str] = None, author: t.Optional[str] = None) -> None:
         """Save the report document to a local HTML file
 
@@ -326,6 +327,7 @@ class Report(DPObjectRef):
             path_uri = f"file://{osp.realpath(osp.expanduser(path))}"
             webbrowser.open_new_tab(path_uri)
 
+    @capture_event("CLI Report Preview")
     def preview(self, width: int = 960, height: int = 700):
         """
         Preview the document inside your currently running Jupyter notebook
