@@ -17,7 +17,7 @@ from datapane.common import NPath
 from .report import blocks as b
 from .report.core import Report
 
-__all__ = ["add_code", "add_header", "add_footer", "build_md_report", "build_demo_report"]
+__all__ = ["add_code", "add_header", "add_footer", "build_md_report", "build_demo_report", "gen_df", "gen_table_df"]
 
 
 def _map_page_blocks(page: b.Page, f: t.Callable[[b.BlockList], b.BlockList]) -> b.Page:
@@ -118,6 +118,19 @@ def add_footer(report: Report, footer: b.BlockOrPrimitive, all_pages: bool = Tru
     )
 
 
+def gen_df(dim: int = 4) -> pd.DataFrame:
+    """Return a test simple df"""
+    axis = [i for i in range(0, dim)]
+    data = {"x": axis, "y": axis}
+    return pd.DataFrame.from_dict(data)
+
+
+def gen_table_df(rows: int = 4, alphabet: str = "ABCDEF") -> pd.DataFrame:
+    """Return a test complex df for adding to a DataTable"""
+    data = [{x: random.randint(0, 1000) for x in alphabet} for _ in range(0, rows)]
+    return pd.DataFrame.from_dict(data)
+
+
 def build_demo_report() -> Report:
     """
     Generate a sample demo report
@@ -133,11 +146,6 @@ def build_demo_report() -> Report:
     from bokeh.plotting import figure  # noqa
     import folium  # noqa
 
-    def gen_df(dim: int = 4) -> pd.DataFrame:
-        axis = [i for i in range(0, dim)]
-        data = {"x": axis, "y": axis}
-        return pd.DataFrame.from_dict(data)
-
     def gen_bokeh(**kw):
         p = figure(title="simple line example", x_axis_label="x", y_axis_label="y", **kw)
         p.line([1, 2, 3, 4, 5], [6, 7, 2, 4, 5], legend_label="Temp.", line_width=2)
@@ -170,10 +178,6 @@ def build_demo_report() -> Report:
     def color_large_vals(s):
         return ["background-color: rgba(255, 0, 0, 0.3)" if val > 800 else "" for val in s]
 
-    def gen_table_df(rows: int = 4, alphabet: str = "ABCDEF") -> pd.DataFrame:
-        data = [{x: random.randint(0, 1000) for x in alphabet} for _ in range(0, rows)]
-        return pd.DataFrame.from_dict(data)
-
     def gen_folium():
         return folium.Map(location=[45.372, -121.6972], zoom_start=12, tiles="Stamen Terrain")
 
@@ -227,7 +231,7 @@ dp.Plot(altair_plot, caption="A Plot")
 
 ## Other Blocks
 
-Datapane has many other block types, including files, embeds, images, and big numbers - see the Blocks page for more info.
+Datapane has many other block types, including formulas, files, embeds, images, and big numbers - see the Blocks page for more info.
 
 Additionally layout blocks provide the ability nest blocks to create groups of columns and user selections - see the Layout page for more info.
 
@@ -239,6 +243,7 @@ Additionally layout blocks provide the ability nest blocks to create groups of c
     other = b.Group(
         b.File(file=logo),
         b.BigNumber(heading="Datapane Blocks", value=11, prev_value=6, is_upward_change=True),
+        b.Formula(r"\frac{1}{\sqrt{x^2 + 1}}", caption="Simple formula"),
         rows=1,
         columns=0,
     )
@@ -301,7 +306,7 @@ dp.Select(group1, df)
         title="Layout",
     )
 
-    adv_blocks = """
+    adv_blocks = r"""
 A list and demonstration of all the blocks supported by Datapane - see https://docs.datapane.com/reports/blocks for more info.
 
 ## Plot Blocks
@@ -332,6 +337,7 @@ dp.DataTable(df, caption="Interactive DataTable")
 ```python
 dp.Text("Hello, __world__!")
 dp.Code("print('Hello, world!')")
+dp.Formula(r"\frac{1}{\sqrt{x^2 + 1}}")
 dp.HTML("<h1>Hello World</h1>")
 dp.BigNumber(heading="Datapane Blocks", value=11, prev_value=6, is_upward_change=True)
 ```
@@ -360,8 +366,7 @@ dp.File(data=[1,2,3], is_json=False)  # store as a pickle
 ```
 
 {{files}}
-
-    """
+"""
 
     plots = b.Group(
         b.Plot(vega_sine, name="vega", caption="Altair Plot"),
@@ -375,11 +380,12 @@ dp.File(data=[1,2,3], is_json=False)  # store as a pickle
     tables = b.Group(
         b.Table(df1, name="table1", caption="Basic Table"),
         b.Table(styler1, name="styled-table", caption="Styled Table"),
-        b.DataTable(gen_table_df(1000000), name="data_table", caption="Interactive DataTable"),
+        b.DataTable(gen_table_df(1000), name="data_table", caption="Interactive DataTable"),
     )
     text = b.Group(
         b.Text("Hello, __world__!", name="markdown"),
         b.Code("print('Hello, world!'", name="code"),
+        b.Formula(r"\frac{1}{\sqrt{x^2 + 1}}"),
         b.HTML("<h1>Hello World</h1>", name="HTML"),
         b.BigNumber(heading="Datapane Blocks", value=11, prev_value=6, is_upward_change=True, name="big_num"),
         rows=1,
