@@ -12,6 +12,7 @@ from .dp_types import (
     PKL_MIMETYPE,
     SECS_1_HOUR,
     SECS_1_WEEK,
+    SIZE_1_MB,
     TD_1_DAY,
     TD_1_HOUR,
     URL,
@@ -21,6 +22,7 @@ from .dp_types import (
     JList,
     NPath,
     SDict,
+    SSDict,
     SList,
     get_dp_mode,
     set_dp_mode,
